<?php
//Setting classes for body element
function layoutstudio_preprocess_page(&$variables) {
	
	//Support "Disable Drupal blocks/regions" option in panels for secondary & tertiary regions
	if ($variables['secondary']) {
		$variables['secondary_display'] = TRUE;	
	}
	else {
		$variables['secondary_display'] = FALSE;	
	}
	if ($variables['tertiary']) {
		$variables['tertiary_display'] = TRUE;	
	}
	else {
		$variables['tertiary_display'] = FALSE;	
	}

	if (module_exists('panels')) {
		if (!$variables['show_blocks']) {
			$variables['secondary_display'] = FALSE;
			$variables['tertiary_display'] = FALSE;
		}
	}

	form_clean_id(NULL, TRUE);
	// Set up layout variable.
  $variables['layout'] = 'no-secondary-tertiary';
  if (!$variables['secondary_display'] && !$variables['tertiary_display']) {
  	$variables['layout'] = 'no-secondary-and-tertiary';
  }
  elseif (!$variables['secondary_display']) {
  	$variables['layout'] = 'no-secondary';
  }
  elseif (!$variables['tertiary_display']) {
  	$variables['layout'] = 'no-tertiary';
  }
  else {
  	$variables['layout'] = 'regions-all';
  }
  
  //Preface region body class
	$variables['preface_class'] = 'no-preface';
  if (!empty($variables['preface'])) {
    $variables['preface_class'] = 'no-preface';
  }
  //Postscript region body class
  $variables['postscript_class'] = 'no-postscript';
  if (!empty($variables['postscript'])) {
    $variables['postscript_class'] = 'no-postscript';
  }
	
  // Compile a list of classes that are going to be applied to the body element.
  // This allows advanced theming based on context (home page, node of certain type, etc.).
  $body_classes = array();
  // Random body class
  $random = layoutstudio_theme_get_setting('layoutstudio_random_class');
  if($random > 1){
    $body_classes[] = 'random-'.rand(1, $random);
  }
  // Add a class that tells us whether we're on the front page or not.
  $body_classes[] = $variables['is_front'] ? 'front' : 'not-front';
  // Add a class that tells us whether the page is viewed by an authenticated user or not.
  $body_classes[] = $variables['logged_in'] ? 'logged-in' : 'not-logged-in';
  // Add arg(0) to make it possible to theme the page depending on the current page
  // type (e.g. node, admin, user, etc.). To avoid illegal characters in the class,
  // we're removing everything disallowed. We are not using 'a-z' as that might leave
  // in certain international characters (e.g. German umlauts).
  $body_classes[] = preg_replace('![^abcdefghijklmnopqrstuvwxyz0-9-_]+!s', '', 'page-'. form_clean_id(drupal_strtolower(arg(0))));
  // If on an individual node page, add the node type.
  if (isset($variables['node']) && $variables['node']->type) {
    $body_classes[] = 'node-type-'. form_clean_id($variables['node']->type);
    if(is_numeric(arg(1))){
    	$body_classes[] = 'node-'. arg(1);
    }
  }
  // Current active menu item
 	$body_classes[] = preg_replace('![^abcdefghijklmnopqrstuvwxyz0-9-_]+!s', '', 'menu-item-'. drupal_strtolower(menu_get_active_title()));
  // Add information regarding the secondary & tertiary.
  if ($variables['layout'] == 'regions-all') {
    $body_classes[] = 'regions-all';
  }
  elseif ($variables['layout'] == 'no-secondary-tertiary') {
    $body_classes[] = 'no-secondary-tertiary';
  }
  else {
    $body_classes[] = $variables['layout'];
  }
  $body_classes[] = $variables['preface_class'];

  if (!$variables['is_front']) {
		// Add unique classes for each page and website section
		$path = drupal_get_path_alias($_GET['q']);
		list($section, $sub_section) = explode('/', $path, 3);
		$body_classes[] = 'section-'. $section;
		$body_classes[] = 'sub-section-'. ($sub_section ? $sub_section : 'none');
		if (arg(0) == 'node') {
			if (arg(1) == 'add') {
				if ($section == 'node') {
					array_pop($body_classes); // Remove 'section-node'
					array_pop($body_classes); // Remove 'section-node'
				}
				$body_classes[] = 'section-node-add'; // Add 'section-node-add'
			}
			elseif (is_numeric(arg(1)) && (arg(2) == 'edit' || arg(2) == 'delete')) {
				if ($section == 'node') {
					array_pop($body_classes); // Remove 'section-node'
					array_pop($body_classes); // Remove 'section-node'
				}
				$body_classes[] = 'section-node-'. arg(2); // Add 'section-node-edit' or 'section-node-delete'
			}
		}
	}
  // Implode with spaces.
  $variables['body_classes'] .= ' ' . implode(' ', $body_classes);

	//Show or hide breadcrumbs option
	$variables['breadcrumb_display'] = layoutstudio_theme_get_setting('layoutstudio_breadcrumb_display');

	//Create Skip to Navigation and Content links
	$variables['skip_to_links'] = '';
  if ($variables['navigation'] OR $variables['primary_links'] OR $variables['secondary_links']) {
  	$skip_to_content ='<span class="skip-to-content"><a href="#content-area" title="Go to site content">content</a></span>';
  	$skip_to_nav = ' &ndash; <span class="skip-to-nav"><a href="#nav" title="Go to site navigation">navigation</a></span>';
  	$variables['skip_to_links'] = '<p class="skip-to-links">Skip to: ' . $skip_to_content . $skip_to_nav . '</p>';
  }	

  // Add dimensions and other layout specific styles.
  $layout = layoutstudio_theme_get_setting('layoutstudio_layout');
  $page_width = check_plain(layoutstudio_theme_get_setting('layoutstudio_page_width'));
  $secondary_width = check_plain(layoutstudio_theme_get_setting('layoutstudio_secondary_width'));
  $tertiary_width = check_plain(layoutstudio_theme_get_setting('layoutstudio_tertiary_width'));
  $primary_width = $page_width - ($secondary_width + $tertiary_width);
  $viewport_regions = layoutstudio_theme_get_setting('layoutstudio_viewport_regions');
  
  if (empty($layout) && user_access('administer site configuration')) {
    global $theme_key;
    drupal_set_message(t('A layout has not been selected for this theme yet. Go to the settings page for your theme to select a layout and configure other settings.'), 'warning');
  }

  if ($layout != 'layout9') {
		//Determine if any regions need to be full browser width
		if (count($viewport_regions) <= 1) {
			$data .= "#page { width: " . $page_width ."px; margin: 0px auto; }\r\n";
		}
		else {
			foreach($viewport_regions as $k => $v) {
				if($v) { // Full width regions
					$data .= "#" . $k . " .inside { margin: 0px auto; width: " . $page_width ."px; } #content .inside .inside { margin: 0; width: auto; }\r\n";
					$data .= "#breadcrumb { width: " . $page_width ."px; margin: 0px auto; }\r\n";
				}
				if (!$v) { //Not full width regions
					$data .= "#" . $k . " { margin: 0px auto; width: " . $page_width ."px; }\r\n";
				}
			}
		}

		//Give regions their dimensions
		$data .= '#primary, #secondary, #tertiary { display: inline; float: left; }';
		$data .= '#primary { width: ' . $primary_width . 'px;}';
		$data .= '.no-secondary-and-tertiary #primary { display: block; float: none; width: auto; position: static; }';
		$data .= '#secondary { width: ' . $secondary_width . 'px;}'; 
		$data .= '#tertiary { width: ' . $tertiary_width . 'px;}';
		
		// Create Layouts
		switch($layout) {
			
			case 'layout1':
				// secondary on the left, primary in the middle, tertiary on the right
				$data .= '#primary, #secondary { position: relative; }';
				$data .= "#primary { left: " . $secondary_width . "px; }\r\n";
				$data .= "#secondary { left: -" . $primary_width . "px; }\r\n";
				$data .= ".no-secondary #primary { position: static; width: " . ($primary_width + $secondary_width) . "px; }\r\n";
				$data .= ".no-tertiary #primary { width: " . ($primary_width + $tertiary_width) . "px; }\r\n";
				$data .= ".no-tertiary #secondary { left: -" . ($primary_width + $tertiary_width) . "px; }\r\n";
			break;
			
			case 'layout2':
				// tertiary on the left, primary in the middle, secondary on the right
				$data .= '#primary, #secondary, #tertiary { position: relative; }';
				$data .= "#primary { left: " . $tertiary_width . "px; }\r\n";
				$data .= "#secondary { left: " . $tertiary_width . "px; }\r\n";
				$data .= "#tertiary { left: -" . ($page_width - $tertiary_width) . "px; }\r\n";
				$data .= ".no-secondary #primary { width: " . ($primary_width + $secondary_width) . "px; }\r\n";
				$data .= ".no-tertiary #primary { position: static; width: " . ($primary_width + $tertiary_width) . "px; }\r\n";
				$data .= ".no-tertiary #secondary { position: static; }\r\n";
			break;
			
			case 'layout3':
				$data .= ".no-secondary #primary { width: " . ($primary_width + $secondary_width) . "px; }\r\n";
				$data .= ".no-tertiary #primary { width: " . ($primary_width + $tertiary_width) . "px; }\r\n";
			break;
			
			case 'layout4':
				// primary left, sidebar second in the middle, and sidebar first on the right
				$data .= '#secondary, #tertiary { position: relative; }';
				$data .= "#secondary { left: " . $tertiary_width . "px; }\r\n";
				$data .= "#tertiary { left: -" . $secondary_width . "px; }\r\n";
				$data .= ".no-secondary #primary { width: " . ($primary_width + $secondary_width) . "px; }\r\n";
				$data .= ".no-tertiary #primary { width: " . ($primary_width + $tertiary_width) . "px; }\r\n";
				$data .= ".no-secondary #tertiary, .no-tertiary #secondary { position: static; }\r\n";
			break;
			
			case 'layout5':
				// secondary on the left, tertiary in the middle, and primary on the right
				$data .= '#primary, #secondary, #tertiary { position: relative; }';
				$data .= "#primary { left: " . ($secondary_width + $tertiary_width) . "px; }\r\n";
				$data .= "#secondary { left: -" . $primary_width . "px; }\r\n";
				$data .= "#tertiary { left: -" . ($page_width - $tertiary_width - $secondary_width) . "px; }\r\n";
				$data .= ".no-secondary #primary { left: " . $tertiary_width . "px; width: " . ($primary_width + $secondary_width) . "px; }\r\n";
				$data .= ".no-secondary #tertiary { left: -" . ($page_width - $tertiary_width) . "px; }\r\n";
				$data .= ".no-tertiary #primary { left: " . $secondary_width . "px; width: " . ($primary_width + $tertiary_width) . "px; }\r\n";
				$data .= ".no-tertiary #secondary { left: -" . ($primary_width + $tertiary_width) . "px; }\r\n";
			break;
			
			case 'layout6':
				// tertiary on the left, secondary in the middle, primary on the right
				$data .= '#primary, #secondary, #tertiary { position: relative; }';
				$data .= "#primary { left: " . ($secondary_width + $tertiary_width) . "px; }\r\n";
				$data .= "#secondary { left: -" . ($primary_width - $tertiary_width) . "px; }\r\n";
				$data .= "#tertiary { left: -" . ($page_width - $tertiary_width) . "px; }\r\n";
				$data .= ".no-secondary #primary { left: " . $tertiary_width . "px; width: " . ($primary_width + $secondary_width) . "px; }\r\n";
				$data .= ".no-secondary #tertiary { left: -" . ($page_width - $tertiary_width) . "px; }\r\n";
				$data .= ".no-tertiary #primary { left: " . $secondary_width . "px; width: " . ($primary_width + $tertiary_width) . "px; }\r\n";
				$data .= ".no-tertiary #secondary { left: -" . ($primary_width + $tertiary_width) . "px; }\r\n";
			break;
			
			case 'layout7':
				// primary on top, secondary and 
				$data .= "#primary { display: block; float:none; width: auto;  }\r\n";
				$data .= "#secondary { width: " . $secondary_width . "px; }\r\n";
				$data .= "#tertiary { width: " . ($page_width - $secondary_width) . "px; }\r\n";
				$data .= ".no-secondary #tertiary, .no-tertiary #secondary { width: auto; }\r\n";
			break;
			
			case 'layout8':
				// stacked full widths.. do I really need to add the widhts here?
				$data .= "#primary, #secondary, #tertiary { display: block; float:none; width: auto; }\r\n";
			break;
		}

  $variables['layoutstudio_layout_styles'] = '<style type="text/css" media="all">' . $data . '</style>';

	}
	
}
//Setting classes for nodes
function layoutstudio_preprocess_node(&$variables) {
	// Compile a list of classes that are going to be applied to the node div.
  $node_classes = array();
  if ($variables['sticky']) {
		$node_classes[] = 'sticky';
	}
	if ($variables['promote']) {
		$node_classes[] = 'promoted';
	}
	if (!$variables['node']->status) {
		$node_classes[] = 'node-unpublished';
		$variables['unpublished'] = TRUE;
	}
	else {
		$variables['unpublished'] = FALSE;
	}
	if ($variables['node']->uid && $variables['node']->uid == $user->uid) {
		// Node is authored by current user
		$node_classes[] = 'user-me';
	}
	//Add node's user id
	$node_classes[] = 'user-' . $variables['node']->uid;
	
	if ($variables['teaser']) {
		// Node is displayed as teaser
		$node_classes[] = 'node-teaser';
	}
	else {
		$node_classes[] = 'node-full';
	}
	//odd/even class for node listings
	$node_classes[] = $variables['zebra'];
	//node count for node listings
	$node_classes[] = 'count-' . $variables['id'];
	// Class for node type: "node-type-page", "node-type-story", "node-type-my-custom-type", etc.
	$node_classes[] = 'node node-type-'. $variables['node']->type;
	$variables['node_classes'] = implode(' ', $node_classes); // Concatenate with spaces  
}

//Setting classes for blocks
function layoutstudio_preprocess_block(&$variables) {
	$block_classes = array();
  // Random block class
  $random = layoutstudio_theme_get_setting('layoutstudio_random_class');
  if($random > 1){
    $block_classes[] = 'random-'.rand(1, $random);
  }
  $block_classes[] = 'block block-'. $variables['block']->module;
  $block_classes[] = $variables['block_zebra'];
  $block_classes[] = 'region-count-'. $variables['block_id'];
  $variables['block_classes'] = implode(' ', $block_classes);
}

//Setting classes for comments
function layoutstudio_preprocess_comment(&$variables) {
  static $comment_counter = array();
  
  if(!isset($comment_counter[$variables['node']->nid])) {
    $comment_counter[$variables['node']->nid] = 1; 
  }
  $comment_classes = array();
  $comment_classes[] = ($comment_counter[$variables['node']->nid] % 2) ? 'odd' : 'even';
  $comment_classes[] = 'comment-'.$variables['comment']->cid;
  $variables['comment_classes'] = implode(' ', $comment_classes);
  $comment_counter[$variables['node']->nid]++; 
}

/**
 * Helper function that loads a theme setting. Using this function allows for theme settings to be overridden on specific
 * pages via the LayoutStudio Extras module.
 */
function layoutstudio_theme_get_setting($setting_name, $refresh = FALSE) {
  if (module_exists('layoutstudio_extras')) {
    if (function_exists('layoutstudio_extras_theme_get_setting')) {
      // Load a theme setting via the LayoutStudio Extras companion module, which will determine if a default setting has
      // been overridden via an adjustment for the current page.
      return layoutstudio_extras_theme_get_setting($setting_name, $refresh);
    }
  }

  // Load the setting the normal way if LayoutStudio Extras is not installed.
  return theme_get_setting($setting_name, $refresh);
}